@@ -4,7 +4,7 @@
 package POE::Resource::FileHandles;
 
 use vars qw($VERSION);
-$VERSION = '1.280'; # NOTE - Should be #.### (three decimal places)
+$VERSION = '1.294'; # NOTE - Should be #.### (three decimal places)
 
 # These methods are folded into POE::Kernel;
 package POE::Kernel;
@@ -183,10 +183,10 @@ sub _data_handle_finalize {
 ### access mode.
 
 sub _data_handle_enqueue_ready {
-  my ($self, $mode, @filenos) = @_;
+  my ($self, $mode) = splice(@_, 0, 2);
 
   my $now = time();
-  foreach my $fileno (@filenos) {
+  foreach my $fileno (@_) {
     if (ASSERT_DATA) {
       _trap "internal inconsistency: undefined fileno" unless defined $fileno;
     }
@@ -207,15 +207,12 @@ sub _data_handle_enqueue_ready {
     # later dispatch happens.
     next unless exists $kr_filenos{$fileno};
 
-    my $kr_fno_rec = $kr_filenos{$fileno}->[$mode];
+    # Gather and dispatch all the events for this fileno/mode pair.
 
-    # Gather all the events to emit for this fileno/mode pair.
-
-    my @selects = map { values %$_ } values %{ $kr_fno_rec->[FMO_SESSIONS] };
-
-    # Emit them.
-
-    foreach my $select (@selects) {
+    foreach my $select (
+      map { values %$_ }
+      values %{ $kr_filenos{$fileno}[$mode][FMO_SESSIONS] }
+    ) {
       $self->_dispatch_event(
         $select->[HSS_SESSION], $select->[HSS_SESSION],
         $select->[HSS_STATE], ET_SELECT, [
@@ -755,7 +752,7 @@ classes that manage them.
 POE watches I/O based on filehandles rather than file descriptors,
 which means there can be clashes between its API and an underlying
 descriptor-based event loop.  This is usually not a problem, but it
-may require work-arounds in certain edge cases.
+may require a work-around in certain edge cases.
 
 =head1 AUTHORS & COPYRIGHTS
 
