@@ -3,7 +3,7 @@ package POE::Wheel::ReadWrite;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '1.280'; # NOTE - Should be #.### (three decimal places)
+$VERSION = '1.294'; # NOTE - Should be #.### (three decimal places)
 
 use Carp qw( croak carp );
 use POE qw(Wheel Driver::SysRW Filter::Line);
@@ -99,8 +99,8 @@ sub new {
         $mark_errors++;
       }
     }
-    if (defined($params{HighMark}) xor defined($params{HighEvent})) {
-      carp "HighMark and HighEvent parameters require each-other";
+    if (defined $params{HighEvent} and not defined $params{HighMark}) {
+      carp "HighEvent requires a corresponding HighMark";
       $mark_errors++;
     }
     if (defined($params{LowMark}) xor defined($params{LowEvent})) {
@@ -229,7 +229,7 @@ sub _define_write_state {
         $$event_flushed && $k->call($me, $$event_flushed, $unique_id);
       }
     }
- );
+  );
 
   $poe_kernel->select_write($self->[HANDLE_OUTPUT], $self->[STATE_WRITE]);
 
@@ -795,7 +795,7 @@ TODO - Example.
 =head4 OutputFilter
 
 InputFilter and OutputFilter may be used to specify different filters
-for input and output.  Please see L</InputFilter> for more informatin
+for input and output. Please see L</InputFilter> for more information
 and an example.
 
 =head4 InputEvent
@@ -875,11 +875,20 @@ error event is dispatched.
 C<ARG3> contains the wheel's unique ID.  The wheel's ID is used to
 differentiate between many wheels managed by a single session.
 
+ErrorEvent may also indicate EOF on a FileHandle by returning
+operation "read" error 0.  For sockets, this means the remote end has
+closed the connection.
+
 A sample ErrorEvent handler:
 
   sub error_state {
     my ($operation, $errnum, $errstr, $id) = @_[ARG0..ARG3];
-    warn "Wheel $id encountered $operation error $errnum: $errstr\n";
+    if ($operation eq "read" and $errnum == 0) {
+      print "EOF from wheel $id\n";
+    }
+    else {
+      warn "Wheel $id encountered $operation error $errnum: $errstr\n";
+    }
     delete $_[HEAP]{wheels}{$id}; # shut down that wheel
   }
 
@@ -941,7 +950,7 @@ put() accepts a list of RECORDS, which will be serialized by the
 wheel's Filter and buffered and written by its Driver.
 
 put() returns true if a HighMark has been set and the Driver's output
-buffer has reached or exceded the limit.  False is returned if
+buffer has reached or exceeded the limit.  False is returned if
 HighMark has not been set, or if the Driver's buffer is smaller than
 that limit.
 
@@ -954,7 +963,7 @@ syntax if HighMark isn't set: the application will fail spectacularly!
 
 event() allows an application to modify the events emitted by a
 POE::Wheel::ReadWrite object.  All constructor parameters ending in
-"Event" may be changed at runtime: L</InputEvent>, L</FlushedEvent>,
+"Event" may be changed at run time: L</InputEvent>, L</FlushedEvent>,
 L</ErrorEvent>, L</HighEvent>, and L</LowEvent>.
 
 Setting an event to undef will disable the code within the wheel that
@@ -1023,7 +1032,7 @@ TODO - Example.
 Sets the high water mark---the number of octets that designates a
 "full enough" output buffer.  A POE::Wheel::ReadWrite object will emit
 a HighEvent when its output buffer expands to reach this point.  All
-put() calls will reutrn true when the output buffer is equal or
+put() calls will return true when the output buffer is equal or
 greater than HIGH_MARK_OCTETS.
 
 Both HighEvent and put() indicate that it's unsafe to continue writing
@@ -1083,7 +1092,7 @@ TODO - Example.
 
 =head2 get_output_handle
 
-get_input_handle() returns the filehandle being watched for input.
+get_output_handle() returns the filehandle being watched for output.
 
 Manipulating filehandles that are managed by POE may cause nasty side
 effects, which may change from one POE release to the next.  Please
@@ -1097,7 +1106,7 @@ Call shutdown($fh,0) on a POE::Wheel::ReadWrite object's input
 filehandle.  This only works for sockets; nothing will happen for
 other types of filehandle.
 
-tionally, the POE::Wheel::ReadWrite object will stop monitoring
+Occasionally, the POE::Wheel::ReadWrite object will stop monitoring
 its input filehandle for new data.  This occurs regardless of the
 filehandle type.
 
@@ -1109,8 +1118,8 @@ Call shutdown($fh,1) on a POE::Wheel::ReadWrite object's output
 filehandle.  This only works for sockets; nothing will happen for
 other types of filehandle.
 
-tionally, the POE::Wheel::ReadWrite object will stop monitoring its
-output filehandle for new data.  This occurs regardless of the
+Occasionally, the POE::Wheel::ReadWrite object will stop monitoring its
+output filehandle for new data. This occurs regardless of the
 filehandle type.
 
 TODO - Example.
@@ -1126,7 +1135,7 @@ TODO - Example.
 =head2 get_driver_out_messages
 
 L<POE::Driver> objects' output buffers may be message based.  Every put()
-call may be buffered individualy.  get_driver_out_messages() will
+call may be buffered individually.  get_driver_out_messages() will
 return the number of pending put() messages that remain to be sent.
 
 Stream-based drivers will simply return 1 if any data remains to be
