@@ -3,13 +3,16 @@ package POE::Wheel::SocketFactory;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '1.280'; # NOTE - Should be #.### (three decimal places)
+$VERSION = '1.294'; # NOTE - Should be #.### (three decimal places)
 
 use Carp qw( carp croak );
 use Symbol qw( gensym );
 
 use Fcntl qw(F_GETFL F_SETFL O_NONBLOCK);
-use Errno qw(EWOULDBLOCK EADDRNOTAVAIL EINPROGRESS EADDRINUSE);
+use Errno qw(
+  EWOULDBLOCK EADDRNOTAVAIL EINPROGRESS EADDRINUSE ECONNABORTED
+  ESPIPE
+);
 use Socket qw(
   AF_INET SOCK_STREAM SOL_SOCKET AF_UNIX PF_UNIX 
   PF_INET SOCK_DGRAM SO_ERROR unpack_sockaddr_in 
@@ -182,7 +185,8 @@ sub _define_accept_state {
           $unique_id
         );
       }
-      elsif ($! != EWOULDBLOCK) {
+      elsif ($! != EWOULDBLOCK and $! != ECONNABORTED and $! != ESPIPE) {
+        # OSX reports ESPIPE, which isn't documented anywhere.
         $$event_failure && $k->call(
           $me, $$event_failure,
           'accept', ($!+0), $!, $unique_id
@@ -1222,7 +1226,7 @@ work where establishing connections normally would block.
 
 =head2 new
 
-new() creats a new POE::Wheel::SocketFactory object.  For sockets
+new() creates a new POE::Wheel::SocketFactory object.  For sockets
 which listen() for and accept() connections, the wheel will generate
 new sockets for each accepted client.  Socket factories for one-shot
 sockets, such as UDP peers or clients established by connect() only
@@ -1350,7 +1354,7 @@ TODO - Example.
 
 =head3 Connecting the Socket to a Remote Endpoint
 
-A socket may either listen for connections to arrive, intitate
+A socket may either listen for connections to arrive, initiate
 connections to a remote endpoint, or be connectionless (such as in the
 case of UDP sockets).
 
@@ -1435,14 +1439,14 @@ client.
 =head4 FailureEvent
 
 C<FailureEvent> names the event POE::Wheel::SocketFactory will emit
-whenever something goes wrong.  It ususally represents some kind of
+whenever something goes wrong.  It usually represents some kind of
 built-in function call error.  See L</PUBLIC EVENTS> for details, as
 some errors are handled internally by this wheel.
 
 =head2 event
 
 event() allows a session to change the events emitted by a wheel
-without destrying and re-creating the wheel.  It accepts one or more
+without destroying and re-creating the wheel.  It accepts one or more
 of the events listed in L</PUBLIC EVENTS>.  Undefined event names
 disable those events.
 
@@ -1518,7 +1522,7 @@ listening or connecting.  See below for the differences.
 
 For INET sockets, C<$_[ARG1]> and C<$_[ARG2]> hold the socket's remote
 address and port, respectively.  The address is packed; see
-L<Socket/inet_nota()> if a human-readable version is needed.
+L<Socket/inet_ntoa> if a human-readable version is needed.
 
   sub handle_new_client {
     my $accepted_socket = $_[ARG0];
@@ -1557,7 +1561,8 @@ holds a Perl built-in function name.
 
 C<$_[ARG1]> and C<$_[ARG2]> describe how the operation failed.  They
 contain the numeric and stringified versions of C<$!>, respectively.
-An application cannot merely check C<$!> because
+An application cannot merely check the global C<$!> variable since it
+may change during event dispatch.
 
 Finally, C<$_[ARG3]> contains the ID for the POE::Wheel::SocketFactory
 instance that generated the event.  See L</ID> and L<POE::Wheel/ID>
